pub struct CreateMintManagerCtx {
pub mint_manager: Pubkey,
pub mint: Pubkey,
pub freeze_authority: Pubkey,
pub payer: Pubkey,
pub token_program: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for CreateMintManagerCtx.
Fields
mint_manager: Pubkeymint: Pubkeypayer: Pubkeytoken_program: Pubkeysystem_program: PubkeyTrait Implementations
sourceimpl BorshSerialize for CreateMintManagerCtxwhere
Pubkey: BorshSerialize,
impl BorshSerialize for CreateMintManagerCtxwhere Pubkey: BorshSerialize,
sourceimpl ToAccountMetas for CreateMintManagerCtx
impl ToAccountMetas for CreateMintManagerCtx
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl RefUnwindSafe for CreateMintManagerCtx
impl Send for CreateMintManagerCtx
impl Sync for CreateMintManagerCtx
impl Unpin for CreateMintManagerCtx
impl UnwindSafe for CreateMintManagerCtx