pub struct CreateTransferReceiptCtx {
pub token_manager: Pubkey,
pub transfer_authority: Pubkey,
pub transfer_receipt: Pubkey,
pub payer: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for CreateTransferReceiptCtx.
Fields
token_manager: Pubkeytransfer_receipt: Pubkeypayer: Pubkeysystem_program: PubkeyTrait Implementations
sourceimpl BorshSerialize for CreateTransferReceiptCtxwhere
Pubkey: BorshSerialize,
impl BorshSerialize for CreateTransferReceiptCtxwhere Pubkey: BorshSerialize,
sourceimpl ToAccountMetas for CreateTransferReceiptCtx
impl ToAccountMetas for CreateTransferReceiptCtx
sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl RefUnwindSafe for CreateTransferReceiptCtx
impl Send for CreateTransferReceiptCtx
impl Sync for CreateTransferReceiptCtx
impl Unpin for CreateTransferReceiptCtx
impl UnwindSafe for CreateTransferReceiptCtx