pub struct AddInvalidator {
pub invalidator: Pubkey,
}Expand description
Instruction.
Fields
invalidator: PubkeyTrait Implementations
sourceimpl BorshDeserialize for AddInvalidatorwhere
Pubkey: BorshDeserialize,
impl BorshDeserialize for AddInvalidatorwhere Pubkey: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where R: Read,
sourceimpl BorshSerialize for AddInvalidatorwhere
Pubkey: BorshSerialize,
impl BorshSerialize for AddInvalidatorwhere Pubkey: BorshSerialize,
sourceimpl Discriminator for AddInvalidator
impl Discriminator for AddInvalidator
const DISCRIMINATOR: [u8; 8] = _
fn discriminator() -> [u8; 8]