pub struct Init {
pub ix: InitIx,
}Expand description
Instruction.
Fields
ix: InitIxTrait Implementations
sourceimpl BorshDeserialize for Initwhere
InitIx: BorshDeserialize,
impl BorshDeserialize for Initwhere InitIx: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where R: Read,
sourceimpl Discriminator for Init
impl Discriminator for Init
const DISCRIMINATOR: [u8; 8] = _
fn discriminator() -> [u8; 8]