#[repr(u8)]
pub enum TokenManagerKind { Managed, Unmanaged, Edition, Permissioned, Programmable, }

Variants



Managed

Token a managed rental and will use freeze authority to manage the token



Unmanaged

Token is unmanaged and can be traded freely until expiration



Edition

Token is a metaplex edition and so it uses metaplex program to freeze



Permissioned

Token is owned by the user but permissioned and they can choose to delegate or not allowing transfers



Programmable

Token is a metaplex programmable nft